@@ -7,35 +7,28 @@ test_that("getType of a 'geom'", {
   output <- getType(x = gtGeoms$polygon)
 
   expect_character(x = output, len = 2)
-  expect_true(all(output %in% c("vector", "polygon")))
+  expect_true(all(output %in% c("polygon", "polygon")))
 })
 
 test_that("getType of a Spatial* object", {
   output <- getType(x = gtSP$SpatialPolygons)
 
   expect_character(x = output, len = 2)
-  expect_true(all(output %in% c("vector", "SpatialPolygons")))
+  expect_true(all(output %in% c("polygon", "SpatialPolygons")))
 })
 
 test_that("getType of an sf object", {
   output <- getType(x = gtSF$polygon)
 
   expect_character(x = output, len = 2)
-  expect_true(all(output %in% c("vector", "POLYGON")))
-})
-
-test_that("getType of a ppp object", {
-  output <- getType(x = gtPPP)
-
-  expect_character(x = output, len = 2)
-  expect_true(all(output %in% c("vector", "ppp")))
+  expect_true(all(output %in% c("polygon", "POLYGON")))
 })
 
 test_that("getType of a RasterLayer", {
   output <- getType(x = gtRasters$continuous)
 
   expect_character(x = output, len = 2)
-  expect_true(all(output %in% c("raster", "RasterLayer")))
+  expect_true(all(output %in% c("grid", "RasterLayer")))
 })
 
 test_that("getType of any other object", {
