@@ -16,8 +16,7 @@ test_that("output is valid geometry", {
 
 test_that("casting to 'line' works", {
   coords <- data.frame(x = c(40, 70, 70, 50),
-                       y = c(40, 40, 60, 70),
-                       fid = 1)
+                       y = c(40, 40, 60, 70))
 
   # from point to line
   input <- gs_point(anchor = coords)
@@ -33,14 +32,3 @@ test_that("casting to 'line' works", {
   expect_true(output@type == "line")
   expect_data_frame(output@point, any.missing = FALSE, nrows = 5, ncols = 3)
 })
-
-test_that("Error if arguments have wrong value", {
-  coords <- data.frame(x = c(40, 70, 70, 50),
-                       y = c(40, 40, 60, 70))
-  input <- gs_point(anchor = coords)
-
-  expect_error(gs_line(vertices = 4))
-  expect_error(gs_line(anchor = input))
-  expect_error(gs_line(anchor = "bla"))
-  expect_error(gs_line(anchor = coords, vertices = "bla"))
-})
